==> haskell-kan-extensions-5.1-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: kan-extensions
version: 5.1
id: kan-extensions-5.1-Dd7R1R4WNTtFBLHvmNzafp
key: kan-extensions-5.1-Dd7R1R4WNTtFBLHvmNzafp
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/kan-extensions/
synopsis: Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads
description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.
category: Data Structures, Monads, Comonads, Functors
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda
abi: 2088c841aa6fd1913912d21f3eef0d56
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/kan-extensions-5.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/kan-extensions-5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/kan-extensions-5.1
hs-libraries: HSkan-extensions-5.1-Dd7R1R4WNTtFBLHvmNzafp
includes:
    kan-extensions-common.h
depends:
    adjunctions-4.4-3i3OZjvW3GuHlBKRXH8s3W array-0.5.2.0 base-4.10.1.0
    comonad-5.0.3-1wQLfIXhDc15HcgpkWgfSP containers-0.5.10.2
    contravariant-1.4.1-7cEYjzgkYgPFdXWpdMNGgr
    distributive-0.5.3-3QQWO3yfOScASLf5zUz2JE
    free-4.12.4-BRVEwYJYv4A5V92AvKu15Y mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    profunctors-5.2.2-tLOt4dPZZiLCnuqjAhdY2
    semigroupoids-5.2.2-EvqgdOJ7nOu2h6meNBcBgC
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2 transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
abi-depends: adjunctions-4.4-3i3OZjvW3GuHlBKRXH8s3W=e2bf4977e57d54bbf2c4980e907324f0
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             comonad-5.0.3-1wQLfIXhDc15HcgpkWgfSP=0772d58444b5fab8850dd1c606485ec5
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             contravariant-1.4.1-7cEYjzgkYgPFdXWpdMNGgr=5e2c57f6d5adae18dd0e94f3a1c17f3b
             distributive-0.5.3-3QQWO3yfOScASLf5zUz2JE=4194008627baa63a29bcee90329e8d22
             free-4.12.4-BRVEwYJYv4A5V92AvKu15Y=8d9cd2ff8c30864cbc7d98c4b7dcaed5
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             profunctors-5.2.2-tLOt4dPZZiLCnuqjAhdY2=20f9843906eb1a5fcfc2baccf1835360
             semigroupoids-5.2.2-EvqgdOJ7nOu2h6meNBcBgC=bdfdbff5356805a537c879faca62e8aa
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
haddock-html: /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kan-extensions-5.1-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: kan-extensions
version: 5.1
id: kan-extensions-5.1-KEiPxTe0RO2ACcc9tsfmlY
key: kan-extensions-5.1-KEiPxTe0RO2ACcc9tsfmlY
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/kan-extensions/
synopsis: Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads
description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.
category: Data Structures, Monads, Comonads, Functors
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda
abi: b14d076c67dc8be752840c768e084e06
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/kan-extensions-5.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/kan-extensions-5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/kan-extensions-5.1
hs-libraries: HSkan-extensions-5.1-KEiPxTe0RO2ACcc9tsfmlY
includes:
    kan-extensions-common.h
depends:
    adjunctions-4.4-I8u7xAFHfV05Uft8CA6olq array-0.5.2.0 base-4.10.1.0
    comonad-5.0.3-Ck9dBYAfHyFIc1BaCiNPqm containers-0.5.10.2
    contravariant-1.4.1-CaIS0FAz3wNFYESTGhl5v6
    distributive-0.5.3-3QQWO3yfOScASLf5zUz2JE
    free-4.12.4-BBVdGi87jPz9q0jM030R7K mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    profunctors-5.2.2-5deYtNXgJL0Ee5ERglnepT
    semigroupoids-5.2.2-2bs5vQ1feZuAAFZStJotTs
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2 transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
abi-depends: adjunctions-4.4-I8u7xAFHfV05Uft8CA6olq=4d45e37bf204f28a40c84189566413c5
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             comonad-5.0.3-Ck9dBYAfHyFIc1BaCiNPqm=7e7ea4b39ff02efc7ac01e968761a1e5
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             contravariant-1.4.1-CaIS0FAz3wNFYESTGhl5v6=6a3c34b34c4bd5d9276d1724f3d09ec8
             distributive-0.5.3-3QQWO3yfOScASLf5zUz2JE=4194008627baa63a29bcee90329e8d22
             free-4.12.4-BBVdGi87jPz9q0jM030R7K=cbc9c297835dac25a2a575b88d6d69bd
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             profunctors-5.2.2-5deYtNXgJL0Ee5ERglnepT=2ee65ebbde2cecfbb7094181d600e1a2
             semigroupoids-5.2.2-2bs5vQ1feZuAAFZStJotTs=651a2e86241b1238a5f1e8b0fa613965
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
haddock-html: /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
